@@ -177,7 +177,7 @@ class JenkinsExporter(Exporter):
                 # These are known for not having project name
                 if item_class == 'org.jenkinsci.plugins.workflow.support.steps.ExecutorStepExecution$PlaceholderTask':
                     self.logger.warn(
-                        'taskof type "ExecutorStepExecution$PlaceholderTask" does not specify project name'
+                        'task of type "ExecutorStepExecution$PlaceholderTask" does not specify project name'
                     )
 
                     continue
@@ -187,11 +187,21 @@ class JenkinsExporter(Exporter):
                 if 'name' not in item_task:
                     raise Exception(f'task of type "{item_class}" does not specify project name')
 
+                item_task_name = item_task['name']
+
                 if item_class == 'hudson.model.Queue$BuildableItem':
-                    buildable_jobs[item_task['name']] += 1
+                    buildable_jobs[item_task_name] += 1
+
+                elif item_class == 'hudson.model.FreeStyleProject':
+                    buildable_jobs[item_task_name] += 1
 
                 elif item_class == 'hudson.model.Queue$BlockedItem':
-                    blocked_jobs[item_task['name']] += 1
+                    blocked_jobs[item_task_name] += 1
+
+                else:
+                    self.logger.warn(
+                        'task of type "{}" (task name {}) was not recognized'.format(item_class, item_task_name)
+                    )
 
         metric = Gauge(
             'build_count',
